pycocoa.octypes.NSRect_t

Package pycocoa :: Module octypes :: Class NSRect_t |
[frames] | no frames]

# Class NSRect_t

       object --+
                |
        ??._CData --+
                    |
    _ctypes.Structure --+
                        |
               c_struct_t --+
                            |
                           NSRect_t

Known Subclasses:
  - NSRect4_t

ObjC `struct` with fields `origin` and `size` (`NSPoint_t`, `NSSize_t`).

Instance Methods
Inherited from `c_struct_t`: `__repr__`, `__str__` Inherited from `_ctypes.Structure`: `__init__`, `__new__` Inherited from `_CData`: `__ctypes_from_outparam__`, `__hash__`, `__reduce__`, `__setstate__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
| origin = `<Field type=NSPoint_t, ofs=0, size=16>`
| size = `<Field type=NSSize_t, ofs=16, size=16>`

Properties
Inherited from `object`: `__class__`